#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: urls.py 11928 2020-02-17 04:02:19Z Trista $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License, 
# you may not use this file except in compliance with the License. 
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and 
# limitations under the License.
#
# $Author: Trista $
# $Date: 2020-02-17 13:02:19 +0900 (週一, 17 二月 2020) $
# $Revision: 11928 $ 

from django.conf.urls import url

from . import views

#app_name = 'landing'

urlpatterns = [
    url(r'^email$', views.EmailView.as_view(), name='landing_email'),
    url(r'^landing_social$', views.LandingSocialView.as_view(), 
        name='landing_social'),
    url(r'^action', views.showActionFile, name='showActionFile'),
]
